@@ -6,23 +6,14 @@
  * Date        : 2009-04-24
  * Description : Qt model-view for items
  *
- * Copyright (C) 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2011      by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2013      by Michael G. Hansen <mike at mghansen dot de>
- * Copyright (C) 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
- * Copyright (C) 2017      by Simon Frei <freisim93 at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011      by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
+ * SPDX-FileCopyrightText: 2017      by Simon Frei <freisim93 at gmail dot com>
  *
- * This program is free software you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -241,11 +232,11 @@ void DigikamItemView::dragDropSort(const ItemInfo& pick, const QList<ItemInfo>&
     CoreDbOperationGroup group;
     group.setMaximumTime(200);
 
-    foreach (ItemInfo info, infoList)
+    Q_FOREACH (ItemInfo info, infoList)
     {
         if      (!found && info.id() == pick.id())
         {
-            foreach (ItemInfo dropInfo, infos)
+            Q_FOREACH (ItemInfo dropInfo, infos)
             {
                 dropInfo.setManualOrder(counter);
                 counter += (order ? 1 : -1);
@@ -344,7 +335,7 @@ void DigikamItemView::setFaceMode(bool on)
 
         imageFilterModel()->setCategorizationMode(ItemSortSettings::CategoryByFaces);
 
-        emit signalSeparationModeChanged((int)ItemSortSettings::CategoryByFaces);
+        Q_EMIT signalSeparationModeChanged((int)ItemSortSettings::CategoryByFaces);
     }
     else
     {
@@ -357,7 +348,7 @@ void DigikamItemView::setFaceMode(bool on)
         imageFilterModel()->setAllGroupsOpen(open);
         imageFilterModel()->setCategorizationMode((ItemSortSettings::CategorizationMode)separationMode);
 
-        emit signalSeparationModeChanged((int)separationMode);
+        Q_EMIT signalSeparationModeChanged((int)separationMode);
     }
 }
 
@@ -428,7 +419,7 @@ void DigikamItemView::confirmFaces(const QList<QModelIndex>& indexes, int tagId)
         needFastRemove = (d->faceMode && (tagId != album->id()));
     }
 
-    foreach (const QModelIndex& index, indexes)
+    Q_FOREACH (const QModelIndex& index, indexes)
     {
         faces << d->faceDelegate->face(index);
         infos << ItemModel::retrieveItemInfo(index);
@@ -455,7 +446,7 @@ void DigikamItemView::removeFaces(const QList<QModelIndex>& indexes)
     QList<FaceTagsIface> faces;
     QList<QModelIndex> sourceIndexes;
 
-    foreach (const QModelIndex& index, indexes)
+    Q_FOREACH (const QModelIndex& index, indexes)
     {
         faces         << d->faceDelegate->face(index);
         infos         << ItemModel::retrieveItemInfo(index);
@@ -478,7 +469,7 @@ void DigikamItemView::unknownFaces(const QList<QModelIndex>& indexes)
     QList<FaceTagsIface> faces;
     QList<QModelIndex> sourceIndexes;
 
-    foreach (const QModelIndex& index, indexes)
+    Q_FOREACH (const QModelIndex& index, indexes)
     {
         faces         << d->faceDelegate->face(index);
         infos         << ItemModel::retrieveItemInfo(index);
@@ -502,7 +493,7 @@ void DigikamItemView::rejectFaces(const QList<QModelIndex>& indexes)
     QList<FaceTagsIface> faces;
     QList<QModelIndex> sourceIndexes;
 
-    foreach (const QModelIndex& index, indexes)
+    Q_FOREACH (const QModelIndex& index, indexes)
     {
         faces         << d->faceDelegate->face(index);
         infos         << ItemModel::retrieveItemInfo(index);
@@ -536,7 +527,7 @@ void DigikamItemView::ignoreFaces(const QList<QModelIndex>& indexes)
     QList<FaceTagsIface> faces;
     QList<QModelIndex> sourceIndexes;
 
-    foreach (const QModelIndex& index, indexes)
+    Q_FOREACH (const QModelIndex& index, indexes)
     {
         faces         << d->faceDelegate->face(index);
         infos         << ItemModel::retrieveItemInfo(index);
@@ -558,7 +549,7 @@ QList<int> DigikamItemView::getFaceIds(const QList<QModelIndex>& indexes) const
 {
     QList<int> ids;
 
-    foreach (const QModelIndex& index, indexes)
+    Q_FOREACH (const QModelIndex& index, indexes)
     {
         ids << d->faceDelegate->face(index).tagId();
     }
@@ -579,12 +570,16 @@ void DigikamItemView::activated(const ItemInfo& info, Qt::KeyboardModifiers modi
 
         if      (leftClickAction == ApplicationSettings::ShowPreview)
         {
-            emit previewRequested(info);
+            Q_EMIT previewRequested(info);
         }
         else if (leftClickAction == ApplicationSettings::StartEditor)
         {
             openFile(info);
         }
+        else if (leftClickAction == ApplicationSettings::ShowOnTable)
+        {
+            d->utilities->insertToLightTable(allItemInfos(), info, false);
+        }
         else
         {
             d->utilities->openInfosWithDefaultApplication(QList<ItemInfo>() << info);
@@ -598,18 +593,18 @@ void DigikamItemView::activated(const ItemInfo& info, Qt::KeyboardModifiers modi
 
 void DigikamItemView::showContextMenuOnInfo(QContextMenuEvent* event, const ItemInfo& info)
 {
-    emit signalShowContextMenuOnInfo(event, info, QList<QAction*>(), imageFilterModel());
+    Q_EMIT signalShowContextMenuOnInfo(event, info, QList<QAction*>(), imageFilterModel());
 }
 
 void DigikamItemView::showGroupContextMenu(const QModelIndex& index, QContextMenuEvent* event)
 {
     Q_UNUSED(index);
-    emit signalShowGroupContextMenu(event, selectedItemInfosCurrentFirst(), imageFilterModel());
+    Q_EMIT signalShowGroupContextMenu(event, selectedItemInfosCurrentFirst(), imageFilterModel());
 }
 
 void DigikamItemView::showContextMenu(QContextMenuEvent* event)
 {
-    emit signalShowContextMenu(event);
+    Q_EMIT signalShowContextMenu(event);
 }
 
 void DigikamItemView::openFile(const ItemInfo& info)
@@ -777,7 +772,7 @@ void DigikamItemView::scrollTo(const QModelIndex& index, ScrollHint hint)
         return;
     }
 
-    DCategorizedView::scrollTo(index, hint);
+    ItemCategorizedView::scrollTo(index, hint);
 }
 
 } // namespace Digikam
