@@ -6,20 +6,11 @@
  * Date        : 2009-11-14
  * Description : Mysql internal database server
  *
- * Copyright (C) 2009-2011 by Holger Foerster <Hamsi2k at freenet dot de>
- * Copyright (C) 2010-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2016      by Swati Lodha <swatilodha27 at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2011 by Holger Foerster <Hamsi2k at freenet dot de>
+ * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2016      by Swati Lodha <swatilodha27 at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -30,6 +21,7 @@
 #include <QStandardPaths>
 #include <QApplication>
 #include <QMessageBox>
+#include <QTcpServer>
 #include <QDateTime>
 #include <QFileInfo>
 #include <QFile>
@@ -59,7 +51,8 @@ class Q_DECL_HIDDEN DatabaseServer::Private
 public:
 
     explicit Private()
-        : databaseProcess(nullptr)
+        : databaseProcess(nullptr),
+          serverPort(3307)
     {
     }
 
@@ -75,6 +68,8 @@ public:
     QString                fileDataDir;
     QString                actualConfig;
     QString                globalConfig;
+
+    int                    serverPort;
 };
 
 DatabaseServer::DatabaseServer(const DbEngineParameters& params, DatabaseServerStarter* const parent)
@@ -141,7 +136,7 @@ void DatabaseServer::run()
     while (databaseServerStateEnum != stopped);
 
     qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Shutting down database server";
-    emit done();
+    Q_EMIT done();
 }
 
 DatabaseServerError DatabaseServer::startDatabaseProcess()
@@ -189,7 +184,7 @@ void DatabaseServer::stopDatabaseProcess()
 
 #ifdef Q_OS_WIN
 
-    mysqlShutDownArgs << QLatin1String("--port=3307");
+    mysqlShutDownArgs << QString::fromLatin1("--port=%1").arg(d->serverPort);
 
 #else
 
@@ -462,9 +457,10 @@ bool DatabaseServer::checkAndRemoveMysqlLogs() const
 
         if (logFile.open(QFile::ReadOnly) && oldLogFile.open(QFile::Append))
         {
-            QByteArray run("run mysql_upgrade");
+            QByteArray runMaria("run mariadb-upgrade");
+            QByteArray runMysql("run mysql_upgrade");
             QByteArray ba = logFile.readAll();
-            needUpgrade   = ba.contains(run);
+            needUpgrade   = (ba.contains(runMaria) || ba.contains(runMysql));
 
             oldLogFile.write(ba);
             oldLogFile.close();
@@ -479,8 +475,8 @@ bool DatabaseServer::checkAndRemoveMysqlLogs() const
 
     // Clear mysql ib_logfile's in case innodb_log_file_size option changed in last confUpdate
 
-    QFile(QDir(d->dataDir).absoluteFilePath(QLatin1String("ib_logfile0"))).remove();
-    QFile(QDir(d->dataDir).absoluteFilePath(QLatin1String("ib_logfile1"))).remove();
+    //QFile(QDir(d->dataDir).absoluteFilePath(QLatin1String("ib_logfile0"))).remove();
+    //QFile(QDir(d->dataDir).absoluteFilePath(QLatin1String("ib_logfile1"))).remove();
 
     return needUpgrade;
 }
@@ -552,8 +548,23 @@ DatabaseServerError DatabaseServer::startMysqlServer()
 
 #ifdef Q_OS_WIN
 
+    QTcpServer* const server = new QTcpServer();
+
+    if (!server->listen(QHostAddress::LocalHost, d->serverPort))
+    {
+        qCWarning(DIGIKAM_DATABASESERVER_LOG) << "Port 3307 not free for the MySQL server";
+
+        server->listen(QHostAddress::LocalHost, 0);
+        d->serverPort = server->serverPort();
+
+        qCWarning(DIGIKAM_DATABASESERVER_LOG) << "Now use the free port:"  << d->serverPort;
+    }
+
+    server->close();
+    delete server;
+
     mysqldCmdArgs << QLatin1String("--skip-networking=0")
-                  << QLatin1String("--port=3307");
+                  << QString::fromLatin1("--port=%1").arg(d->serverPort);
 
 #else
 
@@ -597,7 +608,7 @@ DatabaseServerError DatabaseServer::initMysqlDatabase() const
 #ifdef Q_OS_WIN
 
         db.setHostName(QLatin1String("localhost"));
-        db.setPort(3307);
+        db.setPort(d->serverPort);
 
 #else
 
@@ -731,7 +742,7 @@ DatabaseServerError DatabaseServer::upgradeMysqlDatabase()
 
 #ifdef Q_OS_WIN
 
-    upgradeCmdArgs << QLatin1String("--port=3307");
+    upgradeCmdArgs << QString::fromLatin1("--port=%1").arg(d->serverPort);
 
 #else
 
