@@ -7,19 +7,10 @@
  * Description : Exiv2 library interface.
  *               Xmp manipulation methods.
  *
- * Copyright (C) 2006-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -67,7 +58,7 @@ bool MetaEngine::canWriteXmp(const QString& filePath)
     catch (Exiv2::AnyError& e)
     {
         qCCritical(DIGIKAM_METAENGINE_LOG) << "Cannot check Xmp access mode with Exiv2:(Error #"
-                                           << e.code() << ": " << QString::fromStdString(e.what()) << ")";
+                                           << (int)e.code() << ": " << QString::fromStdString(e.what()) << ")";
     }
     catch (...)
     {
@@ -1014,7 +1005,11 @@ QVariant MetaEngine::getXmpTagVariant(const char* xmpTagName, bool rationalAsLis
                 case Exiv2::signedShort:
                 case Exiv2::signedLong:
                 {
+#if EXIV2_TEST_VERSION(0,27,99)
+                    return QVariant((int)it->toInt64());
+#else
                     return QVariant((int)it->toLong());
+#endif
                 }
 
                 case Exiv2::unsignedRational:
@@ -1022,6 +1017,15 @@ QVariant MetaEngine::getXmpTagVariant(const char* xmpTagName, bool rationalAsLis
                 {
                     if (rationalAsListOfInts)
                     {
+                        if (!(*it).count())
+                        {
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+                            return QVariant(QMetaType(QMetaType::QVariantList));
+#else
+                            return QVariant(QVariant::List);
+#endif
+                        }
+
                         QList<QVariant> list;
                         list << (*it).toRational().first;
                         list << (*it).toRational().second;
@@ -1030,6 +1034,15 @@ QVariant MetaEngine::getXmpTagVariant(const char* xmpTagName, bool rationalAsLis
                     }
                     else
                     {
+                        if (!(*it).count())
+                        {
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+                            return QVariant(QMetaType(QMetaType::Double));
+#else
+                            return QVariant(QVariant::Double);
+#endif
+                        }
+
                         // prefer double precision
 
                         double num = (*it).toRational().first;
@@ -1037,7 +1050,11 @@ QVariant MetaEngine::getXmpTagVariant(const char* xmpTagName, bool rationalAsLis
 
                         if (den == 0.0)
                         {
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+                            return QVariant(QMetaType(QMetaType::Double));
+#else
                             return QVariant(QVariant::Double);
+#endif
                         }
 
                         return QVariant(num / den);
