@@ -6,18 +6,9 @@
  * Date        : 2020-12-31
  * Description : Online version checker
  *
- * Copyright (C) 2020-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -50,7 +41,6 @@ public:
 
     explicit Private()
       : preRelease  (false),
-        releaseNotes(false),
         redirects   (0),
         curVersion  (QLatin1String(digikam_version_short)),
         curBuildDt  (digiKamBuildDate()),
@@ -60,7 +50,6 @@ public:
     }
 
     bool                   preRelease;          ///< Flag to check pre-releases
-    bool                   releaseNotes;        ///< Flag to indicate release notes downloading
     int                    redirects;           ///< Count of redirected url
 
     QString                curVersion;          ///< Current application version string
@@ -138,29 +127,10 @@ void OnlineVersionChecker::checkForNewVersion()
     }
     else
     {
-        rUrl = QUrl(QLatin1String("https://invent.kde.org/websites/digikam-org/-/raw/master/data/release.yml"));
+        rUrl = QUrl(QLatin1String("https://digikam.org/release.yml"));
     }
 
-    d->redirects    = 0;
-    d->releaseNotes = false;
-    download(rUrl);
-}
-
-void OnlineVersionChecker::downloadReleaseNotes(const QString& version)
-{
-    QUrl rUrl;
-
-    if (version.isEmpty())
-    {
-        rUrl = QUrl(QLatin1String("https://invent.kde.org/graphics/digikam/-/raw/master/NEWS"));
-    }
-    else
-    {
-        rUrl = QUrl(QString::fromLatin1("https://invent.kde.org/graphics/digikam/-/raw/master/project/NEWS.%1").arg(version));
-    }
-
-    d->redirects    = 0;
-    d->releaseNotes = true;
+    d->redirects = 0;
     download(rUrl);
 }
 
@@ -176,7 +146,7 @@ void OnlineVersionChecker::download(const QUrl& url)
 
     if (d->reply->error())
     {
-        emit signalNewVersionCheckError(d->reply->errorString());
+        Q_EMIT signalNewVersionCheckError(d->reply->errorString());
     }
 }
 
@@ -196,7 +166,7 @@ void OnlineVersionChecker::slotDownloadFinished(QNetworkReply* reply)
         (reply->error() != QNetworkReply::InsecureRedirectError))
     {
         qCDebug(DIGIKAM_GENERAL_LOG) << "Error: " << reply->errorString();
-        emit signalNewVersionCheckError(reply->errorString());
+        Q_EMIT signalNewVersionCheckError(reply->errorString());
 
         return;
     }
@@ -217,15 +187,7 @@ void OnlineVersionChecker::slotDownloadFinished(QNetworkReply* reply)
     if (data.isEmpty())
     {
         qCWarning(DIGIKAM_GENERAL_LOG) << "No data returned from the remote connection.";
-        emit signalNewVersionCheckError(i18n("No data returned from the remote connection."));
-
-        return;
-    }
-
-    if (d->releaseNotes)
-    {
-        emit signalReleaseNotesData(data);
-        d->releaseNotes = false;
+        Q_EMIT signalNewVersionCheckError(i18n("No data returned from the remote connection."));
 
         return;
     }
@@ -240,7 +202,7 @@ void OnlineVersionChecker::slotDownloadFinished(QNetworkReply* reply)
 
         if (!OnlineVersionChecker::bundleProperties(arch, ext))
         {
-            emit signalNewVersionCheckError(i18n("Unsupported Architecture: %1", QSysInfo::buildAbi()));
+            Q_EMIT signalNewVersionCheckError(i18n("Unsupported Architecture: %1", QSysInfo::buildAbi()));
 
             qCDebug(DIGIKAM_GENERAL_LOG) << "Unsupported architecture";
 
@@ -267,7 +229,7 @@ void OnlineVersionChecker::slotDownloadFinished(QNetworkReply* reply)
         if (sections.size() < 4)
         {
             qCWarning(DIGIKAM_GENERAL_LOG) << "Invalid file name format returned from the remote connection.";
-            emit signalNewVersionCheckError(i18n("Invalid file name format returned from the remote connection."));
+            Q_EMIT signalNewVersionCheckError(i18n("Invalid file name format returned from the remote connection."));
 
             return;
         }
@@ -292,7 +254,7 @@ void OnlineVersionChecker::slotDownloadFinished(QNetworkReply* reply)
         if (!onlineDt.isValid())
         {
             qCWarning(DIGIKAM_GENERAL_LOG) << "Invalid pre-release date from the remote list.";
-            emit signalNewVersionCheckError(i18n("Invalid pre-release date from the remote list."));
+            Q_EMIT signalNewVersionCheckError(i18n("Invalid pre-release date from the remote list."));
 
             return;
         }
@@ -303,11 +265,11 @@ void OnlineVersionChecker::slotDownloadFinished(QNetworkReply* reply)
 
         if (onlineDt > d->curBuildDt)
         {
-            emit signalNewVersionAvailable(dtStr);            // Forward pre-release build date from remote file.
+            Q_EMIT signalNewVersionAvailable(dtStr);            // Forward pre-release build date from remote file.
         }
         else
         {
-            emit signalNewVersionCheckError(QString());             // Report error to GUI
+            Q_EMIT signalNewVersionCheckError(QString());             // Report error to GUI
         }
     }
     else
@@ -324,7 +286,7 @@ void OnlineVersionChecker::slotDownloadFinished(QNetworkReply* reply)
         if (onlineVals.size() != 3)
         {
             qCWarning(DIGIKAM_GENERAL_LOG) << "Invalid format returned from the remote connection.";
-            emit signalNewVersionCheckError(i18n("Invalid format returned from the remote connection."));
+            Q_EMIT signalNewVersionCheckError(i18n("Invalid format returned from the remote connection."));
 
             return;
         }
@@ -340,11 +302,11 @@ void OnlineVersionChecker::slotDownloadFinished(QNetworkReply* reply)
                                       currVals[1].toInt(),
                                       currVals[2].toInt()))
         {
-            emit signalNewVersionAvailable(onlineVer);
+            Q_EMIT signalNewVersionAvailable(onlineVer);
         }
         else
         {
-            emit signalNewVersionCheckError(QString());
+            Q_EMIT signalNewVersionCheckError(QString());
         }
     }
 }
