@@ -6,7 +6,7 @@
  * Date        : 2008-12-10
  * Description : misc file operation methods
  *
- * SPDX-FileCopyrightText: 2014-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2014-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -542,7 +542,7 @@ bool DFileOperations::renameFile(const QString& srcFile,
 
 bool DFileOperations::copyFile(const QString& srcFile,
                                const QString& dstFile,
-                               bool* const cancel)
+                               const bool* const cancel)
 {
     bool ret = true;
     QString tmpFile(dstFile);
