@@ -6,19 +6,10 @@
  * Date        : 2010-01-16
  * Description : Qt item view for images
  *
- * Copyright (C) 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -127,7 +118,9 @@ ItemViewCategorized::ItemViewCategorized(QWidget* const parent)
 
     // important optimization for layouting
 
+    setBatchSize(100);
     setUniformItemSizes(true);
+    setLayoutMode(QListView::Batched);
 
     // disable "feature" from DCategorizedView
 
@@ -316,7 +309,7 @@ void ItemViewCategorized::setSelectedIndexes(const QList<QModelIndex>& indexes)
 
     QItemSelection mySelection;
 
-    foreach (const QModelIndex& index, indexes)
+    Q_FOREACH (const QModelIndex& index, indexes)
     {
         mySelection.select(index, index);
     }
@@ -357,7 +350,12 @@ void ItemViewCategorized::slotGridSizeChanged(const QSize& gridSize)
 
 void ItemViewCategorized::updateDelegateSizes()
 {
-    QStyleOptionViewItem option = viewOptions();
+    QStyleOptionViewItem option;
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+    initViewItemOption(&option);
+#else
+    option = viewOptions();
+#endif
 /*
     int frameAroundContents = 0;
 
@@ -427,7 +425,7 @@ void ItemViewCategorized::slotClicked(const QModelIndex& index)
 {
     if (d->currentMouseEvent)
     {
-        emit clicked(d->currentMouseEvent, index);
+        Q_EMIT clicked(d->currentMouseEvent, index);
     }
 }
 
@@ -435,7 +433,7 @@ void ItemViewCategorized::slotEntered(const QModelIndex& index)
 {
     if (d->currentMouseEvent)
     {
-        emit entered(d->currentMouseEvent, index);
+        Q_EMIT entered(d->currentMouseEvent, index);
     }
 }
 
@@ -446,8 +444,8 @@ void ItemViewCategorized::reset()
     // FIXME : Emitting this causes a crash importstackedview, because the model is not yet set.
     //         atm there's a check against null models though.
 
-    emit selectionChanged();
-    emit selectionCleared();
+    Q_EMIT selectionChanged();
+    Q_EMIT selectionCleared();
 
     d->ensureInitialSelectedItem = true;
     d->hintAtScrollPosition      = QModelIndex();
@@ -461,11 +459,11 @@ void ItemViewCategorized::selectionChanged(const QItemSelection& selectedItems,
 {
     DCategorizedView::selectionChanged(selectedItems, deselectedItems);
 
-    emit selectionChanged();
+    Q_EMIT selectionChanged();
 
     if (!selectionModel()->hasSelection())
     {
-        emit selectionCleared();
+        Q_EMIT selectionCleared();
     }
 
     userInteraction();
@@ -815,7 +813,7 @@ void ItemViewCategorized::contextMenuEvent(QContextMenuEvent* event)
     }
 }
 
-void ItemViewCategorized::leaveEvent(QEvent*)
+void ItemViewCategorized::leaveEvent(QEvent* event)
 {
     hideIndexNotification();
 
@@ -823,6 +821,8 @@ void ItemViewCategorized::leaveEvent(QEvent*)
     {
         d->mouseButtonPressed = Qt::NoButton;
     }
+
+    DCategorizedView::leaveEvent(event);
 }
 
 void ItemViewCategorized::mousePressEvent(QMouseEvent* event)
@@ -860,7 +860,7 @@ void ItemViewCategorized::mousePressEvent(QMouseEvent* event)
 
     if (!index.isValid())
     {
-        emit viewportClicked(event);
+        Q_EMIT viewportClicked(event);
     }
 }
 
@@ -926,21 +926,23 @@ void ItemViewCategorized::wheelEvent(QWheelEvent* event)
 
         if      (delta > 0)
         {
-            emit zoomInStep();
+            Q_EMIT zoomInStep();
         }
         else if (delta < 0)
         {
-            emit zoomOutStep();
+            Q_EMIT zoomOutStep();
         }
 
         event->accept();
         return;
     }
 
-    if (verticalScrollBarPolicy() == Qt::ScrollBarAlwaysOff && event->orientation() == Qt::Vertical)
+    if (verticalScrollBarPolicy() == Qt::ScrollBarAlwaysOff && event->angleDelta().y() != 0)
     {
-        QWheelEvent n(event->pos(), event->globalPos(), event->angleDelta().y(),
-                      event->buttons(), event->modifiers(), Qt::Horizontal);
+        QWheelEvent n(event->position(), event->globalPosition(), event->pixelDelta(),
+                      event->angleDelta(), event->buttons(), event->modifiers(),
+                      event->phase(), event->inverted(), event->source());
+
         QApplication::sendEvent(horizontalScrollBar(), &n);
         event->setAccepted(n.isAccepted());
     }
@@ -977,15 +979,15 @@ void ItemViewCategorized::keyPressEvent(QKeyEvent* event)
     if (trigger)
     {
         const QModelIndexList indexList = selModel->selectedIndexes();
-        foreach (const QModelIndex& index, indexList)
+        Q_FOREACH (const QModelIndex& index, indexList)
         {
-            emit itemTriggered(itemForIndex(index));
+            Q_EMIT itemTriggered(itemForIndex(index));
         }
     }
 */
     DCategorizedView::keyPressEvent(event);
 
-    emit keyPressed(event);
+    Q_EMIT keyPressed(event);
 }
 
 void ItemViewCategorized::resizeEvent(QResizeEvent* e)
@@ -1021,7 +1023,12 @@ bool ItemViewCategorized::viewportEvent(QEvent* event)
                 break;
             }
 
-            QStyleOptionViewItem option =  viewOptions();
+            QStyleOptionViewItem option;
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+            initViewItemOption(&option);
+#else
+            option = viewOptions();
+#endif
             option.rect                 =  visualRect(index);
             option.state               |= ((index == currentIndex()) ? QStyle::State_HasFocus : QStyle::State_None);
             showToolTip(index, option, he);
@@ -1053,7 +1060,12 @@ void ItemViewCategorized::showIndexNotification(const QModelIndex& index, const
 
     d->notificationToolTip->setTipContents(message);
 
-    QStyleOptionViewItem option = viewOptions();
+    QStyleOptionViewItem option;
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+    initViewItemOption(&option);
+#else
+    option = viewOptions();
+#endif
     option.rect                 = visualRect(index);
     option.state               |= ((index == currentIndex()) ? QStyle::State_HasFocus : QStyle::State_None);
     d->notificationToolTip->show(option, index);
@@ -1078,7 +1090,12 @@ QModelIndex ItemViewCategorized::mapIndexForDragDrop(const QModelIndex& index) c
 
 QPixmap ItemViewCategorized::pixmapForDrag(const QList<QModelIndex>& indexes) const
 {
-    QStyleOptionViewItem option = viewOptions();
+    QStyleOptionViewItem option;
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+    initViewItemOption(&option);
+#else
+    option = viewOptions();
+#endif
     option.rect                 = viewport()->rect();
 
     return d->delegate->pixmapForDrag(option, indexes);
