@@ -6,18 +6,9 @@
  * Date        : 2005-04-02
  * Description : setup Misc tab.
  *
- * Copyright (C) 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -48,7 +39,9 @@ public:
     {
         Behaviour = 0,
         Appearance,
-        System
+        System,
+        SpellCheck,
+        Localize
     };
 
 public:
@@ -56,6 +49,9 @@ public:
     explicit ShowfotoSetupMisc(QWidget* const parent = nullptr);
     ~ShowfotoSetupMisc() override;
 
+    void setActiveTab(MiscTab tab);
+    MiscTab activeTab() const;
+
     bool checkSettings();
     void applySettings();
 
