@@ -6,18 +6,9 @@
  * Date        : 2021-09-27
  * Description : Showfoto stack view favorites list
  *
- * Copyright (C) 2021-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -79,6 +70,7 @@ ShowfotoStackViewFavoriteList::ShowfotoStackViewFavoriteList(ShowfotoStackViewFa
     setAlternatingRowColors(true);
     setColumnCount(1);
     setSortingEnabled(true);
+    setUniformRowHeights(true);
     setAllColumnsShowFocus(true);
     sortByColumn(0, Qt::AscendingOrder);
     setSelectionMode(QAbstractItemView::SingleSelection);
@@ -119,7 +111,7 @@ void ShowfotoStackViewFavoriteList::slotLoadContents()
 
     if (fvitem)
     {
-        emit signalLoadContentsFromFiles(fvitem->urlsToPaths(), fvitem->currentUrl().toLocalFile());
+        Q_EMIT signalLoadContentsFromFiles(fvitem->urlsToPaths(), fvitem->currentUrl().toLocalFile());
     }
 }
 
@@ -203,7 +195,11 @@ void ShowfotoStackViewFavoriteList::dragEnterEvent(QDragEnterEvent* e)
 void ShowfotoStackViewFavoriteList::dragMoveEvent(QDragMoveEvent* e)
 {
     if ((e->source() == this) &&
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+        (dynamic_cast<ShowfotoStackViewFavoriteItem*>(itemAt(e->position().toPoint())) != d->parent->topFavoritesItem()))
+#else
         (dynamic_cast<ShowfotoStackViewFavoriteItem*>(itemAt(e->pos())) != d->parent->topFavoritesItem()))
+#endif
     {
         QTreeWidget::dragMoveEvent(e);
         e->accept();
@@ -216,7 +212,7 @@ void ShowfotoStackViewFavoriteList::dragMoveEvent(QDragMoveEvent* e)
         QList<QUrl> mimeurls = e->mimeData()->urls();
         QList<QUrl> urls;
 
-        foreach (const QUrl& url, mimeurls)
+        Q_FOREACH (const QUrl& url, mimeurls)
         {
             if (isReadableImageFile(url.toLocalFile()))
             {
@@ -246,7 +242,11 @@ void ShowfotoStackViewFavoriteList::dropEvent(QDropEvent* e)
             return;
         }
 
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+        ShowfotoStackViewFavoriteItem* const tgt = dynamic_cast<ShowfotoStackViewFavoriteItem*>(itemAt(e->position().toPoint()));
+#else
         ShowfotoStackViewFavoriteItem* const tgt = dynamic_cast<ShowfotoStackViewFavoriteItem*>(itemAt(e->pos()));
+#endif
 
         if (!tgt)
         {
@@ -278,7 +278,7 @@ void ShowfotoStackViewFavoriteList::dropEvent(QDropEvent* e)
         QList<QUrl> mimeurls = e->mimeData()->urls();
         QList<QUrl> urls;
 
-        foreach (const QUrl& url, mimeurls)
+        Q_FOREACH (const QUrl& url, mimeurls)
         {
             if (isReadableImageFile(url.toLocalFile()))
             {
@@ -290,7 +290,7 @@ void ShowfotoStackViewFavoriteList::dropEvent(QDropEvent* e)
         {
             QTreeWidget::dropEvent(e);
 
-            emit signalAddFavorite(urls, urls.first());
+            Q_EMIT signalAddFavorite(urls, urls.first());
 
             e->acceptProposedAction();
             return;
@@ -300,12 +300,16 @@ void ShowfotoStackViewFavoriteList::dropEvent(QDropEvent* e)
     e->ignore();
 }
 
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+QMimeData* ShowfotoStackViewFavoriteList::mimeData(const QList<QTreeWidgetItem*>& items) const
+#else
 // cppcheck-suppress passedByValue
-QMimeData* ShowfotoStackViewFavoriteList::mimeData(const QList<QTreeWidgetItem*> items) const       // clazy:exclude=function-args-by-ref
+QMimeData* ShowfotoStackViewFavoriteList::mimeData(const QList<QTreeWidgetItem*> items) const     // clazy:exclude=function-args-by-ref
+#endif
 {
     QList<QUrl> urls;
 
-    foreach (QTreeWidgetItem* const itm, items)
+    Q_FOREACH (QTreeWidgetItem* const itm, items)
     {
         ShowfotoStackViewFavoriteItem* const vitem = dynamic_cast<ShowfotoStackViewFavoriteItem*>(itm);
 
@@ -397,7 +401,7 @@ void ShowfotoStackViewFavoriteList::setFilter(const QString& filter, Qt::CaseSen
         ++it;
     }
 
-    emit signalSearchResult(query);
+    Q_EMIT signalSearchResult(query);
 }
 
 QString ShowfotoStackViewFavoriteList::filter() const
