@@ -1347,7 +1347,7 @@ void ImportUI::slotDownload(bool onlySelected, bool deleteAfter, Album* album)
 
                 if (!cl.isAvailable() || cl.isNull())
                 {
-                    QMessageBox::information(this,qApp->applicationName(),
+                    QMessageBox::information(this, qApp->applicationName(),
                                              i18nc("@info", "Collection which host your default target album set to process "
                                                    "download from camera device is not available. Please select another one from "
                                                    "camera configuration dialog."));
@@ -1385,14 +1385,15 @@ void ImportUI::slotDownload(bool onlySelected, bool deleteAfter, Album* album)
             QString header(i18nc("@info", "Please select the destination album from the digiKam library to "
                                  "import the camera pictures into."));
 
-            album = AlbumSelectDialog::selectAlbum(this, dynamic_cast<PAlbum*>(album), header);
+            album  = AlbumSelectDialog::selectAlbum(this, dynamic_cast<PAlbum*>(album), header);
+            pAlbum = dynamic_cast<PAlbum*>(album);
 
-            if (!album)
+            if (!pAlbum)
             {
+                qCDebug(DIGIKAM_IMPORTUI_LOG) << "Destination Album is null";
                 return;
             }
 
-            pAlbum = dynamic_cast<PAlbum*>(album);
             group.writeEntry(d->configLastTargetAlbum, album->globalID());
         }
     }
@@ -1407,6 +1408,17 @@ void ImportUI::slotDownload(bool onlySelected, bool deleteAfter, Album* album)
         return;
     }
 
+    CollectionLocation cl = CollectionManager::instance()->locationForAlbumRootId(pAlbum->albumRootId());
+
+    if (!cl.isAvailable() || cl.isNull())
+    {
+        QMessageBox::information(this, qApp->applicationName(),
+                                 i18nc("@info", "Collection selected as the destination album to download "
+                                       "from the camera device is not available. Please select another "
+                                       "destination album."));
+        return;
+    }
+
     // -- Check disk space ------------------------
     // See bug #139519: Always check free space available before to
     // download items selection from camera.
@@ -1431,6 +1443,16 @@ void ImportUI::slotDownloaded(const QString& folder, const QString& file, const
         QScopedPointer<DMetadata> metadata(new DMetadata(temp));
         QDateTime creationDate = metadata->getItemDateTime();
 
+        if (!creationDate.isValid())
+        {
+            creationDate = tempInfo.birthTime();
+
+            if (!creationDate.isValid())
+            {
+                creationDate = tempInfo.lastModified();
+            }
+        }
+
         if (!createSubAlbums(downloadUrl, tempInfo.suffix(), creationDate))
         {
             downloadUrl = QUrl::fromLocalFile(tempInfo.path());
