@@ -6,19 +6,10 @@
  * Date        : 2008-11-21
  * Description : Batch Queue Manager items list.
  *
- * Copyright (C) 2008-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C)      2014 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
+ * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText:      2014 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -39,9 +30,28 @@
 
 // KDE includes
 
+#if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
+#   pragma GCC diagnostic push
+#   pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
+
+#if defined(Q_CC_CLANG)
+#   pragma clang diagnostic push
+#   pragma clang diagnostic ignored "-Wdeprecated-declarations"
+#endif
+
 #include <kactioncollection.h>
 #include <klocalizedstring.h>
 
+// Restore warnings
+#if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
+#   pragma GCC diagnostic pop
+#endif
+
+#if defined(Q_CC_CLANG)
+#   pragma clang diagnostic pop
+#endif
+
 // Local includes
 
 #include "digikam_debug.h"
@@ -299,18 +309,19 @@ QueueListView::QueueListView(QWidget* const parent)
     setSelectionMode(QAbstractItemView::ExtendedSelection);
     setWhatsThis(i18nc("@info", "This is the list of images to batch process."));
 
-    setAcceptDrops(true);
-    viewport()->setAcceptDrops(true);
-    setDropIndicatorShown(true);
     setDragEnabled(true);
+    setAcceptDrops(true);
+    setDropIndicatorShown(true);
+    viewport()->setAcceptDrops(true);
     viewport()->setMouseTracking(true);
 
-    setSortingEnabled(true);
-    sortByColumn(1,Qt::AscendingOrder);
-    setAllColumnsShowFocus(true);
-    setRootIsDecorated(false);
-    setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     setColumnCount(3);
+    setSortingEnabled(true);
+    setRootIsDecorated(false);
+    setUniformRowHeights(true);
+    setAllColumnsShowFocus(true);
+    sortByColumn(1, Qt::AscendingOrder);
+    setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     setContextMenuPolicy(Qt::CustomContextMenu);
 
     QStringList titles;
@@ -367,14 +378,18 @@ Qt::DropActions QueueListView::supportedDropActions() const
     return (Qt::CopyAction | Qt::MoveAction);
 }
 
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+QMimeData* QueueListView::mimeData(const QList<QTreeWidgetItem*>& items) const
+#else
 // cppcheck-suppress passedByValue
-QMimeData* QueueListView::mimeData(const QList<QTreeWidgetItem*> items) const       // clazy:exclude=function-args-by-ref
+QMimeData* QueueListView::mimeData(const QList<QTreeWidgetItem*> items) const    // clazy:exclude=function-args-by-ref
+#endif
 {
     QList<QUrl> urls;
     QList<int> albumIDs;
     QList<qlonglong> imageIDs;
 
-    foreach (QTreeWidgetItem* const itm, items)
+    Q_FOREACH (QTreeWidgetItem* const itm, items)
     {
         QueueListViewItem* const vitem = dynamic_cast<QueueListViewItem*>(itm);
 
@@ -510,7 +525,7 @@ void QueueListView::dropEvent(QDropEvent* e)
 
             if (vitem && vitem != this)
             {
-                foreach (const ItemInfo& info, imageInfoList)
+                Q_FOREACH (const ItemInfo& info, imageInfoList)
                 {
                     vitem->removeItemByInfo(info);
                 }
@@ -587,7 +602,7 @@ void QueueListView::dropEvent(QDropEvent* e)
         e->ignore();
     }
 
-    emit signalQueueContentsChanged();
+    Q_EMIT signalQueueContentsChanged();
 }
 
 void QueueListView::setEnableToolTips(bool val)
@@ -723,7 +738,7 @@ void QueueListView::slotAddItems(const ItemInfoList& list)
 
     updateDestFileNames();
 
-    emit signalQueueContentsChanged();
+    Q_EMIT signalQueueContentsChanged();
 }
 
 void QueueListView::drawRow(QPainter* p, const QStyleOptionViewItem& opt, const QModelIndex& index) const
@@ -769,21 +784,21 @@ void QueueListView::slotClearList()
 {
     removeItems(Private::ItemsAll);
 
-    emit signalQueueContentsChanged();
+    Q_EMIT signalQueueContentsChanged();
 }
 
 void QueueListView::slotRemoveSelectedItems()
 {
     removeItems(Private::ItemsSelected);
 
-    emit signalQueueContentsChanged();
+    Q_EMIT signalQueueContentsChanged();
 }
 
 void QueueListView::slotRemoveItemsDone()
 {
     removeItems(Private::ItemsDone);
 
-    emit signalQueueContentsChanged();
+    Q_EMIT signalQueueContentsChanged();
 }
 
 void QueueListView::removeItems(int removeType)
@@ -841,7 +856,7 @@ void QueueListView::removeItems(int removeType)
     }
     while (find);
 
-    emit signalQueueContentsChanged();
+    Q_EMIT signalQueueContentsChanged();
 }
 
 void QueueListView::removeItemByInfo(const ItemInfo& info)
@@ -876,7 +891,7 @@ void QueueListView::removeItemById(qlonglong id)
     }
     while (find);
 
-    emit signalQueueContentsChanged();
+    Q_EMIT signalQueueContentsChanged();
 }
 
 bool QueueListView::findItemByInfo(const ItemInfo& info)
@@ -1162,7 +1177,7 @@ void QueueListView::slotCollectionImageChange(const CollectionImageChangeset& ch
         case CollectionImageChangeset::Removed:
         case CollectionImageChangeset::RemovedAll:
         {
-            foreach (const qlonglong& id, changeset.ids())
+            Q_FOREACH (const qlonglong& id, changeset.ids())
             {
                 removeItemById(id);
             }
